{% load i18n %}

<div class="module">
    <table>
        <caption>{% trans "FileBrowser" %}</caption>
        <tr class="row2">
            <th scope="row"><a href="{% url 'fb_browse' %}">{% trans "FileBrowser" %}</a></th>
            <td> </td>
            <td> </td>
        </tr>
    </table>
</div>